@@ -376,7 +376,7 @@ def evaluate_model(recording, model_folder):
             input_filename = "tmp.txt"
             output_filename = "evaluate.pfile"
             with open(input_filename, "w") as f:
-                for symbolnr, instance in enumerate([x, "0"]):
+                for symbolnr, instance in enumerate([(x, "0")]):
                     feature_string, label = instance
                     assert len(feature_string) == feature_count, \
                         "Expected %i features, got %i features" % \
